Module cluster

Module cluster 

Functions

detect_communities
Partition nodes into communities using the Louvain modularity algorithm.
run_clustering
Run community detection on the graph stored in db and persist the results.