Module diff

Module diff 

Structs

GraphDiff
GraphSnapshot
ImpactReport

Functions

compute_impact
Find files changed in the last N days and compute impact.
diff_graphs
Compute the diff between two graph snapshots.
snapshot_at_commit
Take a graph snapshot by parsing the source tree at a specific git commit.