pub fn snapshot_at_commit(
repo_path: &Path,
commit_spec: &str,
) -> Result<GraphSnapshot>Expand description
Take a graph snapshot by parsing the source tree at a specific git commit.
pub fn snapshot_at_commit(
repo_path: &Path,
commit_spec: &str,
) -> Result<GraphSnapshot>Take a graph snapshot by parsing the source tree at a specific git commit.