pub fn slice_hash(summary: &FileSummary) -> StringExpand description
Compute the slice hash for a single file from its FileSummary.
pub fn slice_hash(summary: &FileSummary) -> StringCompute the slice hash for a single file from its FileSummary.