pub enum CommentKind {
Standard,
JsxExpression,
JsxCommentedCode,
}Variants
Standard
Regular JS/JSDoc comment above a function or at the top level
JsxExpression
{/* ... */} expression comment inside JSX return body
JsxCommentedCode
JSX expression comment whose inner text starts with < — commented-out JSX code
Implementations