Module walker

Module walker 

Structs

SourceFile
A source file that has been read from disk and is ready for parsing.

Enums

Language
Source language detected from file extension.

Functions

walk_repo
Walk a repository and return every parseable source file.