pub struct SourceFile {
pub path: PathBuf,
pub relative_path: String,
pub language: Language,
pub content: String,
pub size_bytes: u64,
}Expand description
A source file that has been read from disk and is ready for parsing.
Fields
path: PathBufAbsolute path on disk.
relative_path: StringPath relative to the repo root, used as the stable identifier in the graph.
language: Languagecontent: Stringsize_bytes: u64Trait Implementations
Sourceimpl Clone for SourceFile
impl Clone for SourceFile
Sourcefn clone(&self) -> SourceFile
fn clone(&self) -> SourceFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SourceFile
impl RefUnwindSafe for SourceFile
impl Send for SourceFile
impl Sync for SourceFile
impl Unpin for SourceFile
impl UnsafeUnpin for SourceFile
impl UnwindSafe for SourceFile