Module diff
cgx_
engine
0.4.1
Module diff
Module Items
Structs
Functions
In crate cgx_
engine
cgx_engine
Module
diff
Structs

Graph
Diff
Graph
Snapshot
Impact
Report
Functions

compute_
impact
Find files changed in the last N days and compute impact.
diff_
graphs
Compute the diff between two graph snapshots.
snapshot_
at_
commit
Take a graph snapshot by parsing the source tree at a specific git commit.