Module graph

Module graph 

Structs

CloneRow
A detected code-clone pair stored in the clones table.
Edge
A directed edge in the code knowledge graph.
GraphDb
Handle to the DuckDB database that stores the code knowledge graph.
Node
A node in the code knowledge graph as stored in (and read from) the DuckDB database.
RepoStats
High-level statistics for a fully indexed repository.
SnapshotEntry
A lightweight record of a single git commit used by the timeline view.
TagRow
A comment annotation tag (e.g. @todo, @fixme) stored in the tags table.

Functions

repo_hash

Type Aliases

CommunityRow
(community_id, label, node_count, top_node_ids)
DocsCoverage
(overall_pct, per_community: Vec<(community_id, documented, total)>, undocumented_high_coupling_nodes)
TestCoverageSummary
(overall_pct, tested_count, untested_count, untested_high_coupling_nodes)