Module parser

Module parser 

Structs

CommentTag
A structured annotation extracted from a source comment (e.g. @todo, @deprecated).
EdgeDef
A directed edge as produced by a language parser or the resolver.
NodeDef
A node as produced by a language parser, before being written to the graph DB.
ParseResult
The output of parsing a single source file.
ParserRegistry
Registry that maps Language variants to their LanguageParser implementations.

Enums

CommentKind
EdgeKind
The semantic relationship represented by a graph edge.
NodeKind
The semantic category of a graph node.

Traits

LanguageParser
Trait implemented by every language-specific Tree-sitter parser.