pub fn create_file_nodes(
file_paths: &HashSet<String>,
language: &HashMap<String, &str>,
) -> Vec<NodeDef>Expand description
Create File NodeDefs for every path in file_paths.
These synthetic nodes are added to the graph so that IMPORTS edges
always have a valid destination, even for files that contain no parseable symbols.