Module walker
cgx_
engine
0.4.1
Module walker
Module Items
Structs
Enums
Functions
In crate cgx_
engine
cgx_engine
Module
walker
Structs

File
A source file that has been read from disk and is ready for parsing.
Enums

Language
Source language detected from file extension.
Functions

walk_
repo
Walk a repository and return every parseable source file.